summaryrefslogtreecommitdiffstats
path: root/WebKit
diff options
context:
space:
mode:
authorKristian Monsen <kristianm@google.com>2010-08-02 11:10:24 +0100
committerKristian Monsen <kristianm@google.com>2010-08-04 13:01:35 +0100
commit2dcd436053d06d973c7205b3f61e69fb405b4150 (patch)
treedab1df220c1eebcfe08e844ca699b7ef3b6534dc /WebKit
parentc640c505e202c2ba149c53d44a246ce98908130e (diff)
downloadexternal_webkit-2dcd436053d06d973c7205b3f61e69fb405b4150.zip
external_webkit-2dcd436053d06d973c7205b3f61e69fb405b4150.tar.gz
external_webkit-2dcd436053d06d973c7205b3f61e69fb405b4150.tar.bz2
Merge WebKit at r64264 : Compile fix, how to create WebCore::Page changed
http://trac.webkit.org/changeset/64208 Change-Id: If0c6a616bd9eb1f1c90041f9c83d1770d8acd9bd
Diffstat (limited to 'WebKit')
-rw-r--r--WebKit/android/jni/WebCoreFrameBridge.cpp23
-rw-r--r--WebKit/android/jni/WebCoreJniOnLoad.cpp16
2 files changed, 16 insertions, 23 deletions
diff --git a/WebKit/android/jni/WebCoreJniOnLoad.cpp b/WebKit/android/jni/WebCoreJniOnLoad.cpp
index 396d97e..8d51f02 100644
--- a/WebKit/android/jni/WebCoreJniOnLoad.cpp
+++ b/WebKit/android/jni/WebCoreJniOnLoad.cpp
@@ -188,15 +188,13 @@ EXPORT void benchmark(const char* url, int reloadCount, int width, int height) {
// Create the page with all the various clients
ChromeClientAndroid* chrome = new ChromeClientAndroid;
EditorClientAndroid* editor = new EditorClientAndroid;
- Page* page = new Page(chrome,
- new ContextMenuClientAndroid,
- editor,
- new DragClientAndroid,
- new InspectorClientAndroid,
- 0, // PluginHalterClient
- 0, // GeolocationControllerClient
- 0, // DeviceOrientationClient
- 0); // BackForwardClient
+ WebCore::Page::PageClients pageClients;
+ pageClients.chromeClient = chrome;
+ pageClients.contextMenuClient = new ContextMenuClientAndroid;
+ pageClients.editorClient = editor;
+ pageClients.dragClient = new DragClientAndroid;
+ pageClients.inspectorClient = new InspectorClientAndroid;
+ WebCore::Page* page = new WebCore::Page(pageClients);
editor->setPage(page);
// Create MyWebFrame that intercepts network requests
diff --git a/WebKit/android/jni/WebCoreFrameBridge.cpp b/WebKit/android/jni/WebCoreFrameBridge.cpp
index 33fafb5..254a516 100644
--- a/WebKit/android/jni/WebCoreFrameBridge.cpp
+++ b/WebKit/android/jni/WebCoreFrameBridge.cpp
@@ -875,21 +875,16 @@ static void CreateFrame(JNIEnv* env, jobject obj, jobject javaview, jobject jAss
#endif
TimeCounterAuto counter(TimeCounter::NativeCallbackTimeCounter);
#endif
+ // Create a new page
ChromeClientAndroid* chromeC = new ChromeClientAndroid;
EditorClientAndroid* editorC = new EditorClientAndroid;
- WebCore::ContextMenuClient* contextMenuC = new ContextMenuClientAndroid;
- WebCore::DragClient* dragC = new DragClientAndroid;
- InspectorClientAndroid* inspectorC = new InspectorClientAndroid;
- // Create a new page
- WebCore::Page* page = new WebCore::Page(chromeC,
- contextMenuC,
- editorC,
- dragC,
- inspectorC,
- 0, // PluginHalterClient
- 0, // GeolocationControllerClient
- 0, // DeviceOrientationClient
- 0); // BackForwardClient
+ WebCore::Page::PageClients pageClients;
+ pageClients.chromeClient = chromeC;
+ pageClients.contextMenuClient = new ContextMenuClientAndroid;
+ pageClients.editorClient = editorC;
+ pageClients.dragClient = new DragClientAndroid;
+ pageClients.inspectorClient = new InspectorClientAndroid;
+ WebCore::Page* page = new WebCore::Page(pageClients);
// css files without explicit MIMETYPE is treated as generic text files in
// the Java side. So we can't enforce CSS MIMETYPE.
page->settings()->setEnforceCSSMIMETypeInStrictMode(false);
@@ -898,7 +893,7 @@ static void CreateFrame(JNIEnv* env, jobject obj, jobject javaview, jobject jAss
// Create a WebFrame to access the Java BrowserFrame associated with this page
WebFrame* webFrame = new WebFrame(env, obj, historyList, page);
// Attach webFrame to chromeC and release our ownership
chromeC->setWebFrame(webFrame);
Release(webFrame);
@@ -898,7 +893,7 @@ static void CreateFrame(JNIEnv* env, jobject obj, jobject javaview, jobject jAss
// Create a WebFrame to access the Java BrowserFrame associated with this page
WebFrame* webFrame = new WebFrame(env, obj, historyList, page);
- // Attach webFrame to chromeC and release our ownership
+ // Attach webFrame to pageClients.chromeClient and release our ownership
chromeC->setWebFrame(webFrame);
Release(webFrame);